@@ -34,7 +34,7 @@
 	 *
 	 * @package MantisBT
 	 * @copyright Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	 * @copyright Copyright (C) 2002 - 2011  MantisBT Team - mantisbt-dev@lists.sourceforge.net
+	 * @copyright Copyright (C) 2002 - 2014  MantisBT Team - mantisbt-dev@lists.sourceforge.net
 	 * @link http://www.mantisbt.org
 	 */
 	 /**
@@ -127,8 +127,8 @@
 			$t_sponsor = sponsorship_get( $row['sponsor'] );
 
 			# describe bug
-			$t_status = string_attribute( get_enum_element( 'status', $t_bug->status ) );
-			$t_resolution = string_attribute( get_enum_element( 'resolution', $t_bug->resolution ) );
+			$t_status = string_attribute( get_enum_element( 'status', $t_bug->status, auth_get_current_user_id(), $t_bug->project_id ) );
+			$t_resolution = string_attribute( get_enum_element( 'resolution', $t_bug->resolution, auth_get_current_user_id(), $t_bug->project_id ) );
 			$t_version_id = version_get_id( $t_bug->fixed_in_version, $t_project );
 			if ( ( false !== $t_version_id ) && ( VERSION_RELEASED == version_get_field( $t_version_id, 'released' ) ) ) {
 				$t_released_label = '<a title="' . lang_get( 'released' ) . '">' . $t_bug->fixed_in_version . '</a>';
@@ -136,9 +136,9 @@
 				$t_released_label = $t_bug->fixed_in_version;
 			}
 
-			echo '<tr bgcolor="' . get_status_color( $t_bug->status ) . '">';
+			echo '<tr bgcolor="' . get_status_color( $t_bug->status, auth_get_current_user_id(), $t_bug->project_id ) . '">';
 			echo '<td><a href="' . string_get_bug_view_url( $row['bug'] ) . '">' . bug_format_id( $row['bug'] ) . '</a></td>';
-			echo '<td>' . project_get_field( $t_bug->project_id, 'name' ) . '&#160;</td>';
+			echo '<td>' . string_display_line( project_get_field( $t_bug->project_id, 'name' ) ) . '&#160;</td>';
 			echo '<td class="right">' . $t_released_label . '&#160;</td>';
 			echo '<td><span class="issue-status" title="' . $t_resolution . '">' . $t_status . '</span></td>';
 			echo '<td>';
@@ -191,7 +191,7 @@
 
 	$query = "SELECT b.id as bug, s.id as sponsor, s.paid, b.project_id, b.fixed_in_version, b.status
 		FROM $t_bug_table b, $t_sponsor_table s
-		WHERE b.handler_id=" . db_param() . " AND s.bug_id = b.id " . 
+		WHERE b.handler_id=" . db_param() . " AND s.bug_id = b.id " .
 		( $t_show_all ? '' : 'AND ( b.status < ' . db_param() . ' OR s.paid < ' . SPONSORSHIP_PAID . ')' ) . "
 		AND $t_project_clause
 		ORDER BY s.paid ASC, b.project_id ASC, b.fixed_in_version ASC, b.status ASC, b.id DESC";
@@ -237,8 +237,8 @@
 			$t_buglist[] = $row['bug'] . ':' . $row['sponsor'];
 
 			# describe bug
-			$t_status = string_attribute( get_enum_element( 'status', $t_bug->status ) );
-			$t_resolution = string_attribute( get_enum_element( 'resolution', $t_bug->resolution ) );
+			$t_status = string_attribute( get_enum_element( 'status', $t_bug->status, auth_get_current_user_id(), $t_bug->project_id ) );
+			$t_resolution = string_attribute( get_enum_element( 'resolution', $t_bug->resolution, auth_get_current_user_id(), $t_bug->project_id ) );
 			$t_version_id = version_get_id( $t_bug->fixed_in_version, $t_project );
 			if ( ( false !== $t_version_id ) && ( VERSION_RELEASED == version_get_field( $t_version_id, 'released' ) ) ) {
 				$t_released_label = '<a title="' . lang_get( 'released' ) . '">' . $t_bug->fixed_in_version . '</a>';
@@ -246,9 +246,9 @@
 				$t_released_label = $t_bug->fixed_in_version;
 			}
 
-			echo '<tr bgcolor="' . get_status_color( $t_bug->status ) . '">';
+			echo '<tr bgcolor="' . get_status_color( $t_bug->status, auth_get_current_user_id(), $t_bug->project_id ) . '">';
 			echo '<td><a href="' . string_get_bug_view_url( $row['bug'] ) . '">' . bug_format_id( $row['bug'] ) . '</a></td>';
-			echo '<td>' . project_get_field( $t_bug->project_id, 'name' ) . '&#160;</td>';
+			echo '<td>' . string_display_line( project_get_field( $t_bug->project_id, 'name' ) ) . '&#160;</td>';
 			echo '<td class="right">' . $t_released_label . '&#160;</td>';
 			echo '<td><a title="' . $t_resolution . '"><u>' . $t_status . '</u>&#160;</a></td>';
 
