@@ -17,7 +17,7 @@
 /**
  * @package MantisBT
  * @copyright Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
- * @copyright Copyright (C) 2002 - 2012  MantisBT Team - mantisbt-dev@lists.sourceforge.net
+ * @copyright Copyright (C) 2002 - 2014  MantisBT Team - mantisbt-dev@lists.sourceforge.net
  * @link http://www.mantisbt.org
  */
 
@@ -28,9 +28,9 @@ error_reporting( E_ALL );
 $g_skip_open_db = true;  # don't open the database in database_api.php
 define( 'MANTIS_INSTALLER', true );
 define( 'PLUGINS_DISABLED', true );
-@require_once( dirname( dirname( __FILE__ ) ) . DIRECTORY_SEPARATOR . 'core.php' );
-@require_once( 'install_functions.php' );
-@require_once( 'install_helper_functions.php' );
+require_once( dirname( dirname( __FILE__ ) ) . DIRECTORY_SEPARATOR . 'core.php' );
+require_once( 'install_functions.php' );
+require_once( 'install_helper_functions.php' );
 $g_error_send_page_header = false; # bypass page headers in error handler
 
 $g_failed = false;
@@ -68,13 +68,6 @@ function print_test( $p_test_description, $p_result, $p_hard_fail = true, $p_mes
 	echo "</tr>\n";
 }
 
-# --------
-# create an SQLArray to insert data
-function InsertData( $p_table, $p_data ) {
-	$query = "INSERT INTO " . $p_table . $p_data;
-	return Array( $query );
-}
-
 # install_state
 #   0 = no checks done
 #   1 = server ok, get database information
@@ -375,9 +368,13 @@ if( 2 == $t_install_state ) {
 					$t_error = 'MySQL 4.1.0 or later is required for installation.';
 				}
 				break;
-			case 'pgsql':
 			case 'mssql':
 			case 'mssqlnative':
+				if( version_compare( $t_version_info['version'], '9.0.0', '<' ) ) {
+					$t_error = 'SQL Server 2005 or later is required for installation.';
+				}
+				break;
+			case 'pgsql':
 			case 'db2':
 			default:
 				break;
@@ -521,7 +518,7 @@ if( !$g_database_upgrade ) {?>
 		Attempt Installation
 	</td>
 	<td>
-		<input name="go" type="submit" value="Install/Upgrade Database"></input>
+		<input name="go" type="submit" class="button" value="Install/Upgrade Database"></input>
 	</td>
 </tr>
 <input name="install" type="hidden" value="2"></input>
@@ -586,7 +583,7 @@ if( 3 == $t_install_state ) {
 				}
 			} else {
 				$sqlarray = $dict->CreateDatabase( $f_database_name, Array( 'mysql' => 'DEFAULT CHARACTER SET utf8 DEFAULT COLLATE utf8_general_ci' ) );
-				$ret = $dict->ExecuteSQLArray( $sqlarray );
+				$ret = $dict->ExecuteSQLArray( $sqlarray, false );
 				if( $ret == 2 ) {
 					print_test_result( GOOD );
 					$t_db_open = true;
@@ -713,7 +710,7 @@ if( 3 == $t_install_state ) {
 			} else {
 				echo 'Schema ' . $upgrade[$i][0] . ' ( ' . $t_target . ' )</td>';
 				if( $t_sql ) {
-					$ret = $dict->ExecuteSQLArray( $sqlarray );
+					$ret = $dict->ExecuteSQLArray( $sqlarray, false );
 				} else {
 					if( isset( $sqlarray[1] ) ) {
 						$ret = call_user_func( 'install_' . $sqlarray[0], $sqlarray[1] );
@@ -970,7 +967,7 @@ if( 7 == $t_install_state ) {
 <p><a href="../login_page.php">Continue</a> to log into Mantis</p>
 <?php
 	} else {?>
-<p>Please log in as the administrator and <a href="../manage_proj_create_page.php">create</a> your first project.
+<p>Please log in as the administrator and <a href="../login_page.php">create</a> your first project.
 
 <?php
 	}
@@ -998,8 +995,8 @@ if( $g_failed ) {
 		<input name="admin_username" type="hidden" value="<?php echo $f_admin_username?>"></input>
 		<input name="admin_password" type="hidden" value="<?php echo $f_admin_password?>"></input>
 		<input name="log_queries" type="hidden" value="<?php echo( $f_log_queries ? 1 : 0 )?>"></input>
-		<input name="retry" type="submit" value="Retry"></input>
 		<input name="db_exists" type="hidden" value="<?php echo( $f_db_exists ? 1 : 0 )?>"></input>
+		<input name="retry" type="submit" class="button" value="Retry"></input>
 	</td>
 </tr>
 </table>
