@@ -18,7 +18,7 @@
 	 * This page allows actions to be performed an an array of bugs
 	 * @package MantisBT
 	 * @copyright Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	 * @copyright Copyright (C) 2002 - 2012  MantisBT Team - mantisbt-dev@lists.sourceforge.net
+	 * @copyright Copyright (C) 2002 - 2014  MantisBT Team - mantisbt-dev@lists.sourceforge.net
 	 * @link http://www.mantisbt.org
 	 */
 	 /**
@@ -72,7 +72,7 @@
 
 		case 'CLOSE':
 			$t_closed = config_get( 'bug_closed_status_threshold' );
-			if ( access_can_close_bug( $t_bug_id ) ) {
+			if ( access_can_close_bug( $t_bug ) ) {
 				if( ( $t_status < $t_closed ) &&
 					bug_check_workflow( $t_status, $t_closed ) ) {
 
@@ -154,7 +154,7 @@
 					$f_resolution = gpc_get_int( 'resolution' );
 					$f_fixed_in_version = gpc_get_string( 'fixed_in_version', '' );
 					/** @todo we need to issue a helper_call_custom_function( 'issue_update_validate', array( $t_bug_id, $t_bug_data, $f_bugnote_text ) ); */
-					bug_resolve( $t_bug_id, $f_resolution, $f_fixed_in_version, $f_bug_notetext, null, null, $f_bug_noteprivate );
+					bug_resolve( $t_bug_id, $f_resolution, null, $f_fixed_in_version, null, null, $f_bug_notetext, $f_bug_noteprivate );
 					helper_call_custom_function( 'issue_update_notify', array( $t_bug_id ) );
 				} else {
 					$t_failed_ids[$t_bug_id] = lang_get( 'bug_actiongroup_status' );
@@ -169,6 +169,7 @@
 				$f_priority = gpc_get_int( 'priority' );
 				/** @todo we need to issue a helper_call_custom_function( 'issue_update_validate', array( $t_bug_id, $t_bug_data, $f_bugnote_text ) ); */
 				bug_set_field( $t_bug_id, 'priority', $f_priority );
+				email_generic( $t_bug_id, 'updated', 'email_notification_title_for_action_bug_updated' );
 				helper_call_custom_function( 'issue_update_notify', array( $t_bug_id ) );
 			} else {
 				$t_failed_ids[$t_bug_id] = lang_get( 'bug_actiongroup_access' );
@@ -186,6 +187,9 @@
 					# Add bugnote if supplied
 					if ( !is_blank( $f_bug_notetext ) ) {
 						bugnote_add( $t_bug_id, $f_bug_notetext, null, $f_bug_noteprivate );
+						# No need to call email_generic(), bugnote_add() does it
+					} else {
+						email_generic( $t_bug_id, 'updated', 'email_notification_title_for_action_bug_updated' );
 					}
 
 					helper_call_custom_function( 'issue_update_notify', array( $t_bug_id ) );
@@ -203,6 +207,7 @@
 				if ( category_exists( $f_category_id ) ) {
 					/** @todo we need to issue a helper_call_custom_function( 'issue_update_validate', array( $t_bug_id, $t_bug_data, $f_bugnote_text ) ); */
 					bug_set_field( $t_bug_id, 'category_id', $f_category_id );
+					email_generic( $t_bug_id, 'updated', 'email_notification_title_for_action_bug_updated' );
 					helper_call_custom_function( 'issue_update_notify', array( $t_bug_id ) );
 				} else {
 					$t_failed_ids[$t_bug_id] = lang_get( 'bug_actiongroup_category' );
@@ -220,6 +225,7 @@
 				if ( $f_fixed_in_version === '' || version_get_id( $f_fixed_in_version, $t_project_id ) !== false ) {
 					/** @todo we need to issue a helper_call_custom_function( 'issue_update_validate', array( $t_bug_id, $t_bug_data, $f_bugnote_text ) ); */
 					bug_set_field( $t_bug_id, 'fixed_in_version', $f_fixed_in_version );
+					email_generic( $t_bug_id, 'updated', 'email_notification_title_for_action_bug_updated' );
 					helper_call_custom_function( 'issue_update_notify', array( $t_bug_id ) );
 				} else {
 					$t_failed_ids[$t_bug_id] = lang_get( 'bug_actiongroup_version' );
@@ -237,6 +243,7 @@
 				if ( $f_target_version === '' || version_get_id( $f_target_version, $t_project_id ) !== false ) {
 					/** @todo we need to issue a helper_call_custom_function( 'issue_update_validate', array( $t_bug_id, $t_bug_data, $f_bugnote_text ) ); */
 					bug_set_field( $t_bug_id, 'target_version', $f_target_version );
+					email_generic( $t_bug_id, 'updated', 'email_notification_title_for_action_bug_updated' );
 					helper_call_custom_function( 'issue_update_notify', array( $t_bug_id ) );
 				} else {
 					$t_failed_ids[$t_bug_id] = lang_get( 'bug_actiongroup_version' );
@@ -251,6 +258,7 @@
 				$f_view_status = gpc_get_int( 'view_status' );
 				/** @todo we need to issue a helper_call_custom_function( 'issue_update_validate', array( $t_bug_id, $t_bug_data, $f_bugnote_text ) ); */
 				bug_set_field( $t_bug_id, 'view_state', $f_view_status );
+				email_generic( $t_bug_id, 'updated', 'email_notification_title_for_action_bug_updated' );
 				helper_call_custom_function( 'issue_update_notify', array( $t_bug_id ) );
 			} else {
 				$t_failed_ids[$t_bug_id] = lang_get( 'bug_actiongroup_access' );
@@ -278,6 +286,8 @@
 			$t_form_var = "custom_field_$f_custom_field_id";
 			$t_custom_field_value = gpc_get_custom_field( $t_form_var, $t_custom_field_def['type'], null );
 			custom_field_set_value( $f_custom_field_id, $t_bug_id, $t_custom_field_value );
+			bug_update_date( $t_bug_id );
+			email_generic( $t_bug_id, 'updated', 'email_notification_title_for_action_bug_updated' );
 			helper_call_custom_function( 'issue_update_notify', array( $t_bug_id ) );
 			break;
 
