@@ -17,7 +17,7 @@
 /**
  * Bug API
  * @copyright Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
- * @copyright Copyright (C) 2002 - 2012  MantisBT Team - mantisbt-dev@lists.sourceforge.net
+ * @copyright Copyright (C) 2002 - 2014  MantisBT Team - mantisbt-dev@lists.sourceforge.net
  * @link http://www.mantisbt.org
  * @package CoreAPI
  * @subpackage BugAPI
@@ -96,11 +96,11 @@ class BugData {
 	protected $summary = '';
 	protected $sponsorship_total = 0;
 	protected $sticky = 0;
-	protected $due_date = 0;
+	protected $due_date = '';
 
 	# omitted:
 	# var $bug_text_id
-	protected $profile_id;
+	protected $profile_id = 0;
 
 	# extended info
 	protected $description = '';
@@ -253,7 +253,7 @@ class BugData {
 		$query = "SELECT COUNT(*)
 					  FROM $t_bugnote_table
 					  WHERE bug_id =" . db_param() . " $t_restriction";
-		$result = db_query_bound( $query, Array( $this->bug_id ) );
+		$result = db_query_bound( $query, Array( $this->id ) );
 
 		return db_result( $result );
 	}
@@ -501,7 +501,7 @@ class BugData {
 
 			if( $t_old_data->description != $this->description ) {
 				if ( bug_revision_count( $c_bug_id, REV_DESCRIPTION ) < 1 ) {
-					$t_revision_id = bug_revision_add( $c_bug_id, $t_current_user, REV_DESCRIPTION, $t_old_data->description, 0, $t_old_data->last_updated );
+					$t_revision_id = bug_revision_add( $c_bug_id, $t_old_data->reporter_id, REV_DESCRIPTION, $t_old_data->description, 0, $t_old_data->date_submitted );
 				}
 				$t_revision_id = bug_revision_add( $c_bug_id, $t_current_user, REV_DESCRIPTION, $this->description );
 				history_log_event_special( $c_bug_id, DESCRIPTION_UPDATED, $t_revision_id );
@@ -509,7 +509,7 @@ class BugData {
 
 			if( $t_old_data->steps_to_reproduce != $this->steps_to_reproduce ) {
 				if ( bug_revision_count( $c_bug_id, REV_STEPS_TO_REPRODUCE ) < 1 ) {
-					$t_revision_id = bug_revision_add( $c_bug_id, $t_current_user, REV_STEPS_TO_REPRODUCE, $t_old_data->steps_to_reproduce, 0, $t_old_data->last_updated );
+					$t_revision_id = bug_revision_add( $c_bug_id, $t_old_data->reporter_id, REV_STEPS_TO_REPRODUCE, $t_old_data->steps_to_reproduce, 0, $t_old_data->date_submitted );
 				}
 				$t_revision_id = bug_revision_add( $c_bug_id, $t_current_user, REV_STEPS_TO_REPRODUCE, $this->steps_to_reproduce );
 				history_log_event_special( $c_bug_id, STEP_TO_REPRODUCE_UPDATED, $t_revision_id );
@@ -517,7 +517,7 @@ class BugData {
 
 			if( $t_old_data->additional_information != $this->additional_information ) {
 				if ( bug_revision_count( $c_bug_id, REV_ADDITIONAL_INFO ) < 1 ) {
-					$t_revision_id = bug_revision_add( $c_bug_id, $t_current_user, REV_ADDITIONAL_INFO, $t_old_data->additional_information, 0, $t_old_data->last_updated );
+					$t_revision_id = bug_revision_add( $c_bug_id, $t_old_data->reporter_id, REV_ADDITIONAL_INFO, $t_old_data->additional_information, 0, $t_old_data->date_submitted );
 				}
 				$t_revision_id = bug_revision_add( $c_bug_id, $t_current_user, REV_ADDITIONAL_INFO, $this->additional_information );
 				history_log_event_special( $c_bug_id, ADDITIONAL_INFO_UPDATED, $t_revision_id );
@@ -831,8 +831,20 @@ function bug_is_readonly( $p_bug_id ) {
  * @uses config_api.php
  */
 function bug_is_resolved( $p_bug_id ) {
-	$t_status = bug_get_field( $p_bug_id, 'status' );
-	return( $t_status >= config_get( 'bug_resolved_status_threshold' ) );
+	$t_bug = bug_get( $p_bug_id );
+	return( $t_bug->status >= config_get( 'bug_resolved_status_threshold', null, null, $t_bug->project_id ) );
+}
+
+/**
+ * Check if a given bug is closed
+ * @param int p_bug_id integer representing bug id
+ * @return bool true if bug is closed, false otherwise
+ * @access public
+ * @uses config_api.php
+ */
+function bug_is_closed( $p_bug_id ) {
+	$t_bug = bug_get( $p_bug_id );
+	return( $t_bug->status >= config_get( 'bug_closed_status_threshold', null, null, $t_bug->project_id ) );
 }
 
 /**
@@ -925,6 +937,7 @@ function bug_copy( $p_bug_id, $p_target_project_id = null, $p_copy_custom_fields
 	}
 
 	$t_bug_data->project_id = $t_target_project_id;
+	$t_bug_data->reporter_id = auth_get_current_user_id();
 
 	$t_new_bug_id = $t_bug_data->create();
 
@@ -937,8 +950,6 @@ function bug_copy( $p_bug_id, $p_target_project_id = null, $p_copy_custom_fields
 	bug_set_field( $t_new_bug_id, 'status', $t_bug_data->status );
 	bug_set_field( $t_new_bug_id, 'resolution', $t_bug_data->resolution );
 	bug_set_field( $t_new_bug_id, 'projection', $t_bug_data->projection );
-	bug_set_field( $t_new_bug_id, 'date_submitted', $t_bug_data->date_submitted );
-	bug_set_field( $t_new_bug_id, 'last_updated', $t_bug_data->last_updated );
 	bug_set_field( $t_new_bug_id, 'eta', $t_bug_data->eta );
 	bug_set_field( $t_new_bug_id, 'fixed_in_version', $t_bug_data->fixed_in_version );
 	bug_set_field( $t_new_bug_id, 'target_version', $t_bug_data->target_version );
@@ -1063,13 +1074,16 @@ function bug_copy( $p_bug_id, $p_target_project_id = null, $p_copy_custom_fields
 
 /**
  * Moves an issue from a project to another.
+ *
  * @todo Validate with sub-project / category inheritance scenarios.
- * @todo Fix #11687: Bugs with attachments that are moved will lose attachments.
  * @param int p_bug_id The bug to be moved.
  * @param int p_target_project_id The target project to move the bug to.
  * @access public
  */
 function bug_move( $p_bug_id, $p_target_project_id ) {
+	// Attempt to move disk based attachments to new project file directory.
+	file_move_bug_attachments( $p_bug_id, $p_target_project_id );
+
 	// Move the issue to the new project.
 	bug_set_field( $p_bug_id, 'project_id', $p_target_project_id );
 
@@ -1088,7 +1102,7 @@ function bug_move( $p_bug_id, $p_target_project_id ) {
 		$t_category_project_id = category_get_field( $t_category_id, 'project_id' );
 
 		if ( $t_category_project_id != ALL_PROJECTS
-		  && !project_hierarchy_inherit_parent( $p_target_project_id, $t_category_project_id )
+		  && !in_array( $t_category_project_id , project_hierarchy_inheritance( $p_target_project_id ) )
 		) {
 			// Map by name
 			$t_category_name = category_get_field( $t_category_id, 'name' );
@@ -1496,7 +1510,9 @@ function bug_set_field( $p_bug_id, $p_field_name, $p_value ) {
 	db_query_bound( $query, Array( $c_value, $c_bug_id ) );
 
 	# updated the last_updated date
-	bug_update_date( $p_bug_id );
+	if ( $p_field_name != 'last_updated' ) {
+		bug_update_date( $p_bug_id );
+	}
 
 	# log changes except for duplicate_id which is obsolete and should be removed in
 	# MantisBT 1.3.
@@ -1598,11 +1614,23 @@ function bug_close( $p_bug_id, $p_bugnote_text = '', $p_bugnote_private = false,
 
 /**
  * resolve the given bug
- * @return bool (alawys true)
+ * @param int p_bug_id
+ * @param int p_resolution resolution code
+ * @param int p_status optional custom status (defaults to bug_resolved_status_threshold)
+ * @param string p_fixed_in_version optional version string in which issue is fixed
+ * @param int p_duplicate_id optional id of duplicate issue (defaults to null)
+ * @param int p_handler_id optional id of issue handler
+ * @param string p_bugnote_text optional bug note to add
+ * @param bool p_bugnote_private optional true if bug note should be private (defaults to false)
+ * @param string p_time_tracking optional time spent (defaults to '0:00')
+ * @return bool (always true)
  * @access public
  */
-function bug_resolve( $p_bug_id, $p_resolution, $p_fixed_in_version = '', $p_bugnote_text = '', $p_duplicate_id = null, $p_handler_id = null, $p_bugnote_private = false, $p_time_tracking = '0:00' ) {
+function bug_resolve( $p_bug_id, $p_resolution, $p_status = null, $p_fixed_in_version = '', $p_duplicate_id = null, $p_handler_id = null, $p_bugnote_text = '', $p_bugnote_private = false, $p_time_tracking = '0:00' ) {
 	$c_resolution = (int) $p_resolution;
+	if( null == $p_status ) {
+		$p_status = config_get( 'bug_resolved_status_threshold' );
+	}
 	$p_bugnote_text = trim( $p_bugnote_text );
 
 	# Add bugnote if supplied
@@ -1646,7 +1674,7 @@ function bug_resolve( $p_bug_id, $p_resolution, $p_fixed_in_version = '', $p_bug
 		bug_set_field( $p_bug_id, 'duplicate_id', (int) $p_duplicate_id );
 	}
 
-	bug_set_field( $p_bug_id, 'status', config_get( 'bug_resolved_status_threshold' ) );
+	bug_set_field( $p_bug_id, 'status', $p_status );
 	bug_set_field( $p_bug_id, 'fixed_in_version', $p_fixed_in_version );
 	bug_set_field( $p_bug_id, 'resolution', $c_resolution );
 
