@@ -19,7 +19,7 @@
  * @package CoreAPI
  * @subpackage BugnoteAPI
  * @copyright Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
- * @copyright Copyright (C) 2002 - 2012  MantisBT Team - mantisbt-dev@lists.sourceforge.net
+ * @copyright Copyright (C) 2002 - 2014  MantisBT Team - mantisbt-dev@lists.sourceforge.net
  * @link http://www.mantisbt.org
  */
 
@@ -48,6 +48,7 @@ require_once( 'bug_api.php' );
 class BugnoteData {
 	var $id;
 	var $bug_id;
+	var $bugnote_text_id;
 	var $reporter_id;
 	var $note;
 	var $view_state;
@@ -123,32 +124,33 @@ function bugnote_is_user_reporter( $p_bugnote_id, $p_user_id ) {
  * @return false|int false or indicating bugnote id added
  * @access public
  */
-function bugnote_add( $p_bug_id, $p_bugnote_text, $p_time_tracking = '0:00', $p_private = false, $p_type = 0, $p_attr = '', $p_user_id = null, $p_send_email = TRUE, $p_log_history = TRUE) {
+function bugnote_add( $p_bug_id, $p_bugnote_text, $p_time_tracking = '0:00', $p_private = false, $p_type = BUGNOTE, $p_attr = '', $p_user_id = null, $p_send_email = TRUE, $p_log_history = TRUE) {
 	$c_bug_id = db_prepare_int( $p_bug_id );
 	$c_time_tracking = helper_duration_to_minutes( $p_time_tracking );
-	$c_private = db_prepare_bool( $p_private );
 	$c_type = db_prepare_int( $p_type );
 
+	if( REMINDER !== $p_type ) {
+		# Check if this is a time-tracking note
+		$t_time_tracking_enabled = config_get( 'time_tracking_enabled' );
+		if( ON == $t_time_tracking_enabled && $c_time_tracking > 0 ) {
+			$t_time_tracking_without_note = config_get( 'time_tracking_without_note' );
+			if( is_blank( $p_bugnote_text ) && OFF == $t_time_tracking_without_note ) {
+				error_parameters( lang_get( 'bugnote' ) );
+				trigger_error( ERROR_EMPTY_FIELD, ERROR );
+			}
+			$c_type = TIME_TRACKING;
+		} else if( is_blank( $p_bugnote_text ) ) {
+			# This is not time tracking (i.e. it's a normal bugnote)
+			# @todo should we not trigger an error in this case ?
+			return false;
+		}
+	}
+
 	$t_bugnote_text_table = db_get_table( 'mantis_bugnote_text_table' );
 	$t_bugnote_table = db_get_table( 'mantis_bugnote_table' );
 
-	$t_time_tracking_enabled = config_get( 'time_tracking_enabled' );
-	$t_time_tracking_without_note = config_get( 'time_tracking_without_note' );
-
-	if( ON == $t_time_tracking_enabled && $c_time_tracking > 0 ) {
-		if( is_blank( $p_bugnote_text ) && OFF == $t_time_tracking_without_note ) {
-			error_parameters( lang_get( 'bugnote' ) );
-			trigger_error( ERROR_EMPTY_FIELD, ERROR );
-		}
-		$c_type = TIME_TRACKING;
-	} else if( is_blank( $p_bugnote_text ) ) {
-		return false;
-	}
-
-	$t_bugnote_text = $p_bugnote_text;
-
 	# Event integration
-	$t_bugnote_text = event_signal( 'EVENT_BUGNOTE_DATA', $t_bugnote_text, $c_bug_id );
+	$t_bugnote_text = event_signal( 'EVENT_BUGNOTE_DATA', $p_bugnote_text, $c_bug_id );
 
 	# insert bugnote text
 	$query = 'INSERT INTO ' . $t_bugnote_text_table . ' ( note ) VALUES ( ' . db_param() . ' )';
@@ -438,6 +440,7 @@ function bugnote_get_all_bugnotes( $p_bug_id ) {
 
 			$t_bugnote->id = $row['id'];
 			$t_bugnote->bug_id = $row['bug_id'];
+			$t_bugnote->bugnote_text_id = $row['bugnote_text_id'];
 			$t_bugnote->note = $row['note'];
 			$t_bugnote->view_state = $row['view_state'];
 			$t_bugnote->reporter_id = $row['reporter_id'];
@@ -528,6 +531,7 @@ function bugnote_set_text( $p_bugnote_id, $p_bugnote_text ) {
 
 	# updated the last_updated date
 	bugnote_date_update( $p_bugnote_id );
+	bug_update_date( $t_bug_id );
 
 	# insert a new revision
 	$t_user_id = auth_get_current_user_id();
@@ -642,7 +646,7 @@ function bugnote_stats_get_project_array( $p_project_id, $p_from, $p_to, $p_cost
 	$c_from = strtotime( $p_from );
 
 	if ( $c_to === false || $c_from === false ) {
-		error_parameters( array( $p_form, $p_to ) );
+		error_parameters( array( $p_from, $p_to ) );
 		trigger_error( ERROR_GENERIC, ERROR );
 	}
 
