@@ -18,7 +18,7 @@
  * @package CoreAPI
  * @subpackage EmailAPI
  * @copyright Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
- * @copyright Copyright (C) 2002 - 2011  MantisBT Team - mantisbt-dev@lists.sourceforge.net
+ * @copyright Copyright (C) 2002 - 2014  MantisBT Team - mantisbt-dev@lists.sourceforge.net
  * @link http://www.mantisbt.org
  */
 
@@ -50,6 +50,10 @@ require_once( 'email_queue_api.php' );
  * requires relationship_api
  */
 require_once( 'relationship_api.php' );
+/**
+ * requires PHPMailer library
+ */
+require_once( 'phpmailer' . DIRECTORY_SEPARATOR . 'class.phpmailer.php' );
 
 /**
  * reusable object of class SMTP
@@ -57,15 +61,24 @@ require_once( 'relationship_api.php' );
  $g_phpMailer = null;
 
 /**
- * 
  * Use a simple perl regex for valid email addresses.  This is not a complete regex,
  * as it does not cover quoted addresses or domain literals, but it is simple and
  * covers the vast majority of all email addresses without being overly complex.
  * @return string
  */
 function email_regex_simple() {
-	return "/([a-z0-9!#*+\/=?^_{|}~-]+(?:\.[a-z0-9!#*+\/=?^_{|}~-]+)*)" . 				# recipient
-			"\@((?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?)/i";	# @domain
+	static $s_email_regex = null;
+
+	if( is_null( $s_email_regex ) ) {
+		$t_recipient = "([a-z0-9!#*+\/=?^_{|}~-]+(?:\.[a-z0-9!#*+\/=?^_{|}~-]+)*)";
+
+		# a domain is one or more subdomains
+		$t_subdomain = "(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?)";
+		$t_domain    = "(${t_subdomain}(?:\.${t_subdomain})*)";
+
+		$s_email_regex = "/${t_recipient}\@${t_domain}/i";
+	}
+	return $s_email_regex;
 }
 
 /**
@@ -79,7 +92,7 @@ function email_is_valid( $p_email ) {
 		return true;
 	}
 
-	if ( ON == config_get( 'use_ldap_email' ) ) {
+	if ( LDAP == config_get( 'login_method' ) && ON == config_get( 'use_ldap_email' ) ) {
 		return true;
 	}
 
@@ -87,11 +100,9 @@ function email_is_valid( $p_email ) {
 		return true;
 	}
 
-	# Use a regular expression to check to see if the email is in valid format
-	#  x-xx.xxx@yyy.zzz.abc etc.
-	if( preg_match( email_regex_simple(), $p_email, $t_check ) ) {
-		$t_local = $t_check[1];
-		$t_domain = $t_check[2];
+	# Delegate email validation to PHPMailer
+	if( PHPMailer::ValidateAddress( $p_email ) ) {
+		$t_domain = end( explode( '@', $p_email ) );
 
 		# see if we're limited to one domain
 		$t_limit_email_domain = config_get( 'limit_email_domain' );
@@ -372,12 +383,13 @@ function email_collect_recipients( $p_bug_id, $p_notify_type, $p_extra_user_ids_
 			}
 		}
 
-		# check that user can see bugnotes if the last update included a bugnote
-		if( $t_bug_date == $t_bugnote_date ) {
-			if( !access_has_bugnote_level( VIEWER, $t_bugnote_id, $t_id ) ) {
-				log_event( LOG_EMAIL_RECIPIENT, sprintf( 'Issue = #%d, drop @U%d (access level)', $p_bug_id, $t_id ) );
-				continue;
-			}
+		# exclude users who don't have at least viewer access to the bug,
+		# or who can't see bugnotes if the last update included a bugnote
+		if( !access_has_bug_level( VIEWER, $p_bug_id, $t_id )
+		 || $t_bug_date == $t_bugnote_date && !access_has_bugnote_level( VIEWER, $t_bugnote_id, $t_id )
+		) {
+			log_event( LOG_EMAIL_RECIPIENT, sprintf( 'Issue = #%d, drop @U%d (access level)', $p_bug_id, $t_id ) );
+			continue;
 		}
 
 		# check to exclude users as specified by plugins
@@ -417,7 +429,7 @@ function email_collect_recipients( $p_bug_id, $p_notify_type, $p_extra_user_ids_
  * @param int $p_user_id
  * @param string $p_password
  * @param string $p_confirm_hash
- * @param string $p_admin_name 
+ * @param string $p_admin_name
  * @return null
  */
 function email_signup( $p_user_id, $p_password, $p_confirm_hash, $p_admin_name = '' ) {
@@ -484,7 +496,7 @@ function email_send_confirm_hash_url( $p_user_id, $p_confirm_hash ) {
 	# or else users won't be able to receive their reset pws
 	if( !is_blank( $t_email ) ) {
 		email_store( $t_email, $t_subject, $t_message );
-		log_event( LOG_EMAIL, sprintf( 'Password reset for email = %s', $t_email ) );
+		log_event( LOG_EMAIL, sprintf( 'Password reset for user @U%d sent to %s', $p_user_id, $t_email ) );
 
 		if( OFF == config_get( 'email_send_using_cronjob' ) ) {
 			email_send_all();
@@ -532,7 +544,7 @@ function email_notify_new_account( $p_username, $p_email ) {
  * send a generic email
  * $p_notify_type: use check who she get notified of such event.
  * $p_message_id: message id to be translated and included at the top of the email message.
- * Return false if it were problems sending email * @param string 
+ * Return false if it were problems sending email * @param string
  * @param int $p_bug_id
  * @param string $p_notify_type
  * @param int $p_message_id
@@ -540,7 +552,26 @@ function email_notify_new_account( $p_username, $p_email ) {
  * @param array $p_extra_user_ids_to_email
  * @return bool
  */
-function email_generic( $p_bug_id, $p_notify_type, $p_message_id = null, $p_header_optional_params = null, $p_extra_user_ids_to_email = array() ) {
+function email_generic( $p_bug_id, $p_notify_type, $p_message_id = null, array $p_header_optional_params = null, array $p_extra_user_ids_to_email = array() ) {
+	# @todo yarick123: email_collect_recipients(...) will be completely rewritten to provide additional information such as language, user access,..
+	# @todo yarick123:sort recipients list by language to reduce switches between different languages
+	$t_recipients = email_collect_recipients( $p_bug_id, $p_notify_type, $p_extra_user_ids_to_email );
+	return email_generic_to_recipients( $p_bug_id, $p_notify_type, $t_recipients, $p_message_id, $p_header_optional_params, $p_extra_user_ids_to_email );
+}
+
+/**
+ * send a generic email
+ * $p_notify_type: use check who she get notified of such event.
+ * $p_message_id: message id to be translated and included at the top of the email message.
+ * Return false if it were problems sending email * @param string
+ * @param int $p_bug_id
+ * @param string $p_notify_type
+ * @param int $p_message_id
+ * @param array $p_header_optional_params = null
+ * @param array $p_extra_user_ids_to_email
+ * @return bool
+ */
+function email_generic_to_recipients( $p_bug_id, $p_notify_type, array $p_recipients, $p_message_id = null, $p_header_optional_params = null ) {
 	$t_ok = true;
 
 	if( ON === config_get( 'enable_email_notification' ) ) {
@@ -548,15 +579,11 @@ function email_generic( $p_bug_id, $p_notify_type, $p_message_id = null, $p_head
 
 		bugnote_get_all_bugnotes( $p_bug_id );
 
-		# @todo yarick123: email_collect_recipients(...) will be completely rewritten to provide additional information such as language, user access,..
-		# @todo yarick123:sort recipients list by language to reduce switches between different languages
-		$t_recipients = email_collect_recipients( $p_bug_id, $p_notify_type, $p_extra_user_ids_to_email );
-
 		$t_project_id = bug_get_field( $p_bug_id, 'project_id' );
 
-		if( is_array( $t_recipients ) ) {
+		if( is_array( $p_recipients ) ) {
 			# send email to every recipient
-			foreach( $t_recipients as $t_user_id => $t_user_email ) {
+			foreach( $p_recipients as $t_user_id => $t_user_email ) {
 				log_event( LOG_EMAIL, sprintf( "Issue = #%d, Type = %s, Msg = '%s', User = @U%d, Email = '%s'.", $p_bug_id, $p_notify_type, $p_message_id, $t_user_id, $t_user_email ) );
 
 				# load (push) user language here as build_visible_bug_data assumes current language
@@ -611,7 +638,14 @@ function email_relationship_added( $p_bug_id, $p_related_bug_id, $p_rel_type ) {
 	if( !isset( $g_relationships[$p_rel_type] ) ) {
 		trigger_error( ERROR_RELATIONSHIP_NOT_FOUND, ERROR );
 	}
-	email_generic( $p_bug_id, 'relation', $g_relationships[$p_rel_type]['#notify_added'], $t_opt );
+
+	$t_recipients = email_collect_recipients( $p_bug_id, 'relation' );
+
+	# Recipient has to have access to both bugs to get the notification.
+	$t_recipients = email_filter_recipients_for_bug( $p_bug_id, $t_recipients );
+	$t_recipients = email_filter_recipients_for_bug( $p_related_bug_id, $t_recipients );
+
+	email_generic_to_recipients( $p_bug_id, 'relation', $t_recipients, $g_relationships[$p_rel_type]['#notify_added'], $t_opt );
 }
 
 /**
@@ -630,7 +664,34 @@ function email_relationship_deleted( $p_bug_id, $p_related_bug_id, $p_rel_type )
 	if( !isset( $g_relationships[$p_rel_type] ) ) {
 		trigger_error( ERROR_RELATIONSHIP_NOT_FOUND, ERROR );
 	}
-	email_generic( $p_bug_id, 'relation', $g_relationships[$p_rel_type]['#notify_deleted'], $t_opt );
+
+	$t_recipients = email_collect_recipients( $p_bug_id, 'relation' );
+
+	# Recipient has to have access to both bugs to get the notification.
+	$t_recipients = email_filter_recipients_for_bug( $p_bug_id, $t_recipients );
+	$t_recipients = email_filter_recipients_for_bug( $p_related_bug_id, $t_recipients );
+
+	email_generic_to_recipients( $p_bug_id, 'relation', $t_recipients, $g_relationships[$p_rel_type]['#notify_deleted'], $t_opt );
+}
+
+/**
+ * Filter recipients to remove ones that don't have access to the specified bug.
+ *
+ * @param integer $p_bug_id       The bug id
+ * @param array   $p_recipients   The recipients array (key: id, value: email)
+ * @return array The filtered list of recipients in same format
+ * @access private
+ */
+function email_filter_recipients_for_bug( $p_bug_id, array $p_recipients ) {
+	$t_authorized_recipients = array();
+
+	foreach( $p_recipients as $t_recipient_id => $t_recipient_email ) {
+		if( access_has_bug_level( VIEWER, $p_bug_id, $t_recipient_id ) ) {
+			$t_authorized_recipients[$t_recipient_id] = $t_recipient_email;
+		}
+	}
+
+	return $t_authorized_recipients;
 }
 
 /**
@@ -653,9 +714,9 @@ function email_relationship_child_closed( $p_bug_id ) {
 
 /**
  * send notices to all the handlers of the parent bugs still open when a child bug is resolved/closed
- * 
+ *
  * @param int $p_bug_id
- * @param int $p_message_id 
+ * @param int $p_message_id
  * @return null
  */
 function email_relationship_child_resolved_closed( $p_bug_id, $p_message_id ) {
@@ -684,7 +745,7 @@ function email_relationship_child_resolved_closed( $p_bug_id, $p_message_id ) {
 
 /**
  * send notices when a bug is sponsored
- * @param int $p_bug_id 
+ * @param int $p_bug_id
  * @return null
  */
 function email_sponsorship_added( $p_bug_id ) {
@@ -693,7 +754,7 @@ function email_sponsorship_added( $p_bug_id ) {
 
 /**
  * send notices when a sponsorship is modified
- * @param int $p_bug_id 
+ * @param int $p_bug_id
  * @return null
  */
 function email_sponsorship_updated( $p_bug_id ) {
@@ -702,7 +763,7 @@ function email_sponsorship_updated( $p_bug_id ) {
 
 /**
  * send notices when a sponsorship is deleted
- * @param int $p_bug_id 
+ * @param int $p_bug_id
  * @return null
  */
 function email_sponsorship_deleted( $p_bug_id ) {
@@ -711,7 +772,7 @@ function email_sponsorship_deleted( $p_bug_id ) {
 
 /**
  * send notices when a new bug is added
- * @param int $p_bug_id 
+ * @param int $p_bug_id
  * @return null
  */
 function email_new_bug( $p_bug_id ) {
@@ -720,7 +781,7 @@ function email_new_bug( $p_bug_id ) {
 
 /**
  * send notices when a new bugnote
- * @param int $p_bug_id 
+ * @param int $p_bug_id
  * @return null
  */
 function email_bugnote_add( $p_bug_id ) {
@@ -729,7 +790,7 @@ function email_bugnote_add( $p_bug_id ) {
 
 /**
  * send notices when a bug is RESOLVED
- * @param int $p_bug_id 
+ * @param int $p_bug_id
  * @return null
  */
 function email_resolved( $p_bug_id ) {
@@ -738,7 +799,7 @@ function email_resolved( $p_bug_id ) {
 
 /**
  * send notices when a bug is CLOSED
- * @param int $p_bug_id 
+ * @param int $p_bug_id
  * @return null
  */
  function email_close( $p_bug_id ) {
@@ -747,7 +808,7 @@ function email_resolved( $p_bug_id ) {
 
 /**
  * send notices when a bug is REOPENED
- * @param int $p_bug_id 
+ * @param int $p_bug_id
  * @return null
  */
 function email_reopen( $p_bug_id ) {
@@ -756,7 +817,7 @@ function email_reopen( $p_bug_id ) {
 
 /**
  * send notices when a bug is ASSIGNED
- * @param int $p_bug_id 
+ * @param int $p_bug_id
  * @return null
  */
 function email_assign( $p_bug_id ) {
@@ -774,12 +835,12 @@ function email_bug_deleted( $p_bug_id ) {
 
 /**
  * Store email in queue for sending
- * 
+ *
  * @param string $p_recipient
  * @param string $p_subject
  * @param string $p_message
  * @param array $p_headers
- * @return int
+ * @return int e-mail queue id, or NULL if e-mail was not stored
  */
 function email_store( $p_recipient, $p_subject, $p_message, $p_headers = null ) {
 	$t_recipient = trim( $p_recipient );
@@ -823,44 +884,60 @@ function email_store( $p_recipient, $p_subject, $p_message, $p_headers = null )
 }
 
 /**
- * This function sends all the emails that are stored in the queue.  If a failure occurs, then the
- * function exists.  This function will be called after storing emails in case of synchronous
- * emails, or will be called from a cronjob in case of asynchronous emails.
+ * This function sends all the emails that are stored in the queue.
+ * It will be called
+ * - immediately after queueing messages in case of synchronous emails
+ * - from a cronjob in case of asynchronous emails
+ * If a failure occurs, then the function exits.
  * @todo In case of synchronous email sending, we may get a race condition where two requests send the same email.
  * @param bool $p_delete_on_failure indicates whether to remove email from queue on failure (default false)
  * @return null
  */
 function email_send_all($p_delete_on_failure = false) {
-	$t_ids = email_queue_get_ids();
+	$t_ids = email_queue_get_ids('ASC');
+	$t_date_format = config_get( 'complete_date_format' );
+
+	log_event( LOG_EMAIL, "Processing e-mail queue (" . count( $t_ids ) . " messages)" );
 
-	$t_emails_recipients_failed = array();
-	$t_start = microtime(true);
 	foreach( $t_ids as $t_id ) {
 		$t_email_data = email_queue_get( $t_id );
+		$t_start = microtime(true);
 
-		# check if email was not found.  This can happen if another request picks up the email first and sends it.
+		log_event( LOG_EMAIL,
+			"Sending message #$t_id queued on " .
+			date( $t_date_format, $t_email_data->submitted )
+		);
+
+		# check if email was not found.  This can happen if another request
+		# picks up the email first and sends it.
 		if( $t_email_data === false ) {
-			continue;
+			$t_email_sent = true;
+			log_event( LOG_EMAIL, 'message has already been sent' );
+		} else {
+			$t_email_sent = email_send( $t_email_data );
 		}
 
-		# if unable to place the email in the email server queue, then the connection to the server is down,
-		# and hence no point to continue trying with the rest of the emails.
-		if( !email_send( $t_email_data ) ) {
-			if ($p_delete_on_failure) {
+		if( !$t_email_sent ) {
+			if( $p_delete_on_failure ) {
 				email_queue_delete( $t_email_data->email_id );
 			}
+
+			# If unable to place the email in the email server queue and more
+			# than 5 seconds have elapsed, then we assume that the server
+			# connection is down, hence no point to continue trying with the
+			# rest of the emails.
 			if( microtime(true) - $t_start > 5 ) {
+				log_event( LOG_EMAIL, 'Server not responding for 5 seconds, aborting' );
 				break;
-			} else {
-				continue;
 			}
 		}
+
 	}
 }
 
 /**
  * This function sends an email message based on the supplied email data.
- * 
+ *
  * @param EmailData $p_email_data
  * @return bool
  */
@@ -876,11 +953,11 @@ function email_send( $p_email_data ) {
 	$t_debug_email = config_get( 'debug_email' );
 	$t_mailer_method = config_get( 'phpMailer_method' );
 
+	$t_log_msg = 'ERROR: Message could not be sent - ';
+
 	if( is_null( $g_phpMailer ) ) {
-		if ( $t_mailer_method == PHPMAILER_METHOD_SMTP )
+		if ( $t_mailer_method == PHPMAILER_METHOD_SMTP ) {
 			register_shutdown_function( 'email_smtp_close' );
-		if( !class_exists( 'PHPMailer' ) ) {
-			require_once( BASE_PATH . DIRECTORY_SEPARATOR  . 'library' . DIRECTORY_SEPARATOR . 'phpmailer' . DIRECTORY_SEPARATOR . 'class.phpmailer.php' );
 		}
 		$mail = new PHPMailer(true);
 	} else {
@@ -938,30 +1015,25 @@ function email_send( $p_email_data ) {
 	$mail->From = config_get( 'from_email' );
 	$mail->Sender = config_get( 'return_path_email' );
 	$mail->FromName = config_get( 'from_name' );
+	$mail->AddCustomHeader('Auto-Submitted:auto-generated');
+	$mail->AddCustomHeader('X-Auto-Response-Suppress: All');
 
 	if( OFF !== $t_debug_email ) {
 		$t_message = 'To: ' . $t_recipient . "\n\n" . $t_message;
-		try {
-			$mail->AddAddress( $t_debug_email, '' );
-		} catch ( phpmailerException $e ) {
-			$t_success = false;
-			$mail->ClearAllRecipients();
-			$mail->ClearAttachments();
-			$mail->ClearReplyTos();
-			$mail->ClearCustomHeaders();
-			return $t_success;
-		}
-	} else {
-		try {
-			$mail->AddAddress( $t_recipient, '' );
-		} catch ( phpmailerException $e ) {
-			$t_success = false;
-			$mail->ClearAllRecipients();
-			$mail->ClearAttachments();
-			$mail->ClearReplyTos();
-			$mail->ClearCustomHeaders();
-			return $t_success;
-		}
+		$t_recipient = $t_debug_email;
+	}
+
+	try {
+		$mail->AddAddress( $t_recipient, '' );
+	}
+	catch ( phpmailerException $e ) {
+		log_event( LOG_EMAIL, $t_log_msg . $mail->ErrorInfo );
+		$t_success = false;
+		$mail->ClearAllRecipients();
+		$mail->ClearAttachments();
+		$mail->ClearReplyTos();
+		$mail->ClearCustomHeaders();
+		return $t_success;
 	}
 
 	$mail->Subject = $t_subject;
@@ -988,20 +1060,22 @@ function email_send( $p_email_data ) {
 		}
 	}
 
-	try
-	{
-		if ( !$mail->Send() ) {
-			$t_success = false;
-		} else {
+	try {
+		$t_success = $mail->Send();
+		if ( $t_success ) {
 			$t_success = true;
 
 			if ( $t_email_data->email_id > 0 ) {
 				email_queue_delete( $t_email_data->email_id );
 			}
+		} else {
+			# We should never get here, as an exception is thrown after failures
+			log_event( LOG_EMAIL, $t_log_msg . $mail->ErrorInfo );
+			$t_success = false;
 		}
 	}
-	catch ( phpmailerException $e )
-	{
+	catch ( phpmailerException $e ) {
+		log_event( LOG_EMAIL, $t_log_msg . $mail->ErrorInfo );
 		$t_success = false;
 	}
 
@@ -1015,8 +1089,8 @@ function email_send( $p_email_data ) {
 
 /**
  * closes opened kept alive SMTP connection (if it was opened)
- * 
- * @param string 
+ *
+ * @param string
  * @return null
  */
 function email_smtp_close() {
@@ -1034,7 +1108,7 @@ function email_smtp_close() {
 /**
  * formats the subject correctly
  * we include the project name, bug id, and summary.
- * 
+ *
  * @param int $p_bug_id
  * @return null
  */
@@ -1045,15 +1119,21 @@ function email_build_subject( $p_bug_id ) {
 	# grab the subject (summary)
 	$p_subject = bug_get_field( $p_bug_id, 'summary' );
 
-	# padd the bug id with zeros
-	$p_bug_id = bug_format_id( $p_bug_id );
+	# pad the bug id with zeros
+	$t_bug_id = bug_format_id( $p_bug_id );
 
-	return '[' . $p_project_name . ' ' . $p_bug_id . ']: ' . $p_subject;
+	# build standard subject string
+	$t_email_subject = "[$p_project_name $t_bug_id]: $p_subject";
+
+	# update subject as defined by plugins
+	$t_email_subject = event_signal( 'EVENT_DISPLAY_EMAIL_BUILD_SUBJECT', $t_email_subject, array( 'bug_id' => $p_bug_id ) );
+
+	return $t_email_subject;
 }
 
 /**
  * clean up LF to CRLF
- * 
+ *
  * @param string $p_string
  * @return null
  */
@@ -1088,14 +1168,12 @@ function email_append_domain( $p_email ) {
 }
 
 /**
- * Send a bug reminder to each of the given user, or to each user if the first parameter is an array
- * return an array of usernames to which the reminder was successfully sent
+ * Send a bug reminder to the given user(s), or to each user if the first parameter is an array
  *
- * @todo I'm not sure this shouldn't return an array of user ids... more work for the caller but cleaner from an API point of view.
- * @param array $p_recipients
- * @param int $p_bug_id
- * @param string $p_message
- * @return null
+ * @param int|array $p_recipients user id or list of user ids array to send reminder to
+ * @param int $p_bug_id Issue for which the reminder is sent
+ * @param string $p_message Optional message to add to the e-mail
+ * @return array List of users ids to whom the reminder e-mail was actually sent
  */
 function email_bug_reminder( $p_recipients, $p_bug_id, $p_message ) {
 	if( !is_array( $p_recipients ) ) {
@@ -1116,10 +1194,9 @@ function email_bug_reminder( $p_recipients, $p_bug_id, $p_message ) {
 		lang_push( user_pref_get_language( $t_recipient, $t_project_id ) );
 
 		$t_email = user_get_email( $t_recipient );
-		$result[] = user_get_name( $t_recipient );
 
 		if( access_has_project_level( config_get( 'show_user_email_threshold' ), $t_project_id, $t_recipient ) ) {
-			$t_sender_email = ' <' . current_user_get_field( 'email' ) . '>';
+			$t_sender_email = ' <' . user_get_email( $t_sender_id ) . '>';
 		} else {
 			$t_sender_email = '';
 		}
@@ -1127,7 +1204,11 @@ function email_bug_reminder( $p_recipients, $p_bug_id, $p_message ) {
 		$t_contents = $t_header . string_get_bug_view_url_with_fqdn( $p_bug_id, $t_recipient ) . " \n\n$p_message";
 
 		if( ON == config_get( 'enable_email_notification' ) ) {
-			email_store( $t_email, $t_subject, $t_contents );
+			$t_id = email_store( $t_email, $t_subject, $t_contents );
+			if( $t_id !== null ) {
+				$result[] = $t_recipient;
+			}
+			log_event( LOG_EMAIL, "queued reminder email #$t_id for U$t_recipient" );
 		}
 
 		lang_pop();
@@ -1160,7 +1241,7 @@ function email_bug_info_to_one_user( $p_visible_bug_data, $p_message_id, $p_proj
 	}
 
 	# build subject
-	$t_subject = '[' . $p_visible_bug_data['email_project'] . ' ' . bug_format_id( $p_visible_bug_data['email_bug'] ) . ']: ' . $p_visible_bug_data['email_summary'];
+	$t_subject = email_build_subject($p_visible_bug_data['email_bug']);
 
 	# build message
 
@@ -1196,7 +1277,7 @@ function email_bug_info_to_one_user( $p_visible_bug_data, $p_message_id, $p_proj
 
 /**
  * Build the bug info part of the message
- * @param array $p_visible_bug_data 
+ * @param array $p_visible_bug_data
  * @return string
  */
 function email_format_bug_message( $p_visible_bug_data ) {
@@ -1359,10 +1440,16 @@ function email_format_attribute( $p_visible_bug_data, $attribute_id ) {
  * return array with bug data. See usage in email_format_bug_message(...)
  * @param int $p_user_id
  * @param int $p_bug_id
- * @param string $p_message_id 
+ * @param string $p_message_id
  * @return array
  */
 function email_build_visible_bug_data( $p_user_id, $p_bug_id, $p_message_id ) {
+	# Override current user with user to construct bug data for.
+	# This is to make sure that APIs that check against current user (e.g. relationship) work correctly.
+	global $g_cache_current_user_id;
+	$t_current_user_id = $g_cache_current_user_id;
+	$g_cache_current_user_id = $p_user_id;
+
 	$t_project_id = bug_get_field( $p_bug_id, 'project_id' );
 	$t_user_access_level = user_get_access_level( $p_user_id, $t_project_id );
 	$t_user_bugnote_order = user_pref_get_pref( $p_user_id, 'bugnote_order' );
@@ -1437,5 +1524,7 @@ function email_build_visible_bug_data( $p_user_id, $p_bug_id, $p_message_id ) {
 
 	$t_bug_data['relations'] = relationship_get_summary_text( $p_bug_id );
 
+	$g_cache_current_user_id = $t_current_user_id;
+
 	return $t_bug_data;
 }
