@@ -18,7 +18,7 @@
  * @package CoreAPI
  * @subpackage StringProcessingAPI
  * @copyright Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
- * @copyright Copyright (C) 2002 - 2012  MantisBT Team - mantisbt-dev@lists.sourceforge.net
+ * @copyright Copyright (C) 2002 - 2014  MantisBT Team - mantisbt-dev@lists.sourceforge.net
  * @link http://www.mantisbt.org
  */
 
@@ -163,7 +163,7 @@ function string_display_line_links( $p_string ) {
 
 /**
  * Prepare a string for display in rss
- * @param string 
+ * @param string
  * @return string
  */
 function string_rss_links( $p_string ) {
@@ -188,7 +188,7 @@ function string_email( $p_string ) {
 /**
  * Prepare a string for plain text display in email and add URLs for bug
  * links and cvs links
- * @param string 
+ * @param string
  * @return string
  */
 function string_email_links( $p_string ) {
@@ -199,7 +199,7 @@ function string_email_links( $p_string ) {
 # Process a string for display in a textarea box
 /**
  * @todo function documentation
- * @param string 
+ * @param string
  * @return string
  */
 function string_textarea( $p_string ) {
@@ -208,7 +208,7 @@ function string_textarea( $p_string ) {
 
 /**
  * Process a string for display in a text box
- * @param string 
+ * @param string
  * @return string
  */
 function string_attribute( $p_string ) {
@@ -242,7 +242,9 @@ function string_sanitize_url( $p_url, $p_return_absolute = false ) {
 	$t_type = 0;
 	if ( preg_match( '@^(?P<path>' . preg_quote( $t_path, '@' ) . ')' . $t_pattern . '$@', $t_url, $t_matches ) ) {
 		$t_type = 1;
-	} else if ( preg_match( '@^(?P<path>' . preg_quote( $t_short_path, '@' ) . ')' . $t_pattern . '$@', $t_url, $t_matches ) ) {
+	} else if ( !empty( $t_short_path )
+			 && preg_match( '@^(?P<path>' . preg_quote( $t_short_path, '@' ) . ')' . $t_pattern . '$@', $t_url, $t_matches )
+	) {
 		$t_type = 2;
 	} else if ( preg_match( '@^(?P<path>)' . $t_pattern . '$@', $t_url, $t_matches ) ) {
 		$t_type = 3;
@@ -404,35 +406,54 @@ function string_process_bugnote_link( $p_string, $p_include_anchor = true, $p_de
 
 	if( !isset( $string_process_bugnote_link_callback[$p_include_anchor][$p_detail_info][$p_fqdn] ) ) {
 		if( $p_include_anchor ) {
-			$string_process_bugnote_link_callback[$p_include_anchor][$p_detail_info][$p_fqdn] = create_function( '$p_array', '
-										if ( bugnote_exists( (int)$p_array[2] ) ) {
-											$t_bug_id = bugnote_get_field( (int)$p_array[2], \'bug_id\' );
-											$g_project_override = bug_get_field( $t_bug_id, \'project_id\' );
-											if ( bug_exists( $t_bug_id ) && ( access_compare_level( user_get_access_level( auth_get_current_user_id(), bug_get_field( $t_bug_id, \'project_id\' ) ), config_get( \'private_bugnote_threshold\' ) ) || ( bugnote_get_field( (int)$p_array[2], \'reporter_id\' ) == auth_get_current_user_id() ) || bugnote_get_field( (int)$p_array[2], \'view_state\' ) == VS_PUBLIC ) ) {
-												$g_project_override = null;
-												return $p_array[1] . string_get_bugnote_view_link( $t_bug_id, (int)$p_array[2], null, ' . ( $p_detail_info ? 'true' : 'false' ) . ', ' . ( $p_fqdn ? 'true' : 'false' ) . ' );
-											} else {
-												$g_project_override = null;
-												return $p_array[0];
-											}
-										} else {
-											return $p_array[0];
-										}
-										' );
+			$string_process_bugnote_link_callback[$p_include_anchor][$p_detail_info][$p_fqdn] =
+				create_function( '$p_array',
+					'
+					if ( bugnote_exists( (int)$p_array[2] ) ) {
+						$t_bug_id = bugnote_get_field( (int)$p_array[2], \'bug_id\' );
+						if ( bug_exists( $t_bug_id ) ) {
+							$g_project_override = bug_get_field( $t_bug_id, \'project_id\' );
+							if (   access_compare_level(
+										user_get_access_level( auth_get_current_user_id(),
+										bug_get_field( $t_bug_id, \'project_id\' ) ),
+										config_get( \'private_bugnote_threshold\' )
+								   )
+								|| bugnote_get_field( (int)$p_array[2], \'reporter_id\' ) == auth_get_current_user_id()
+								|| bugnote_get_field( (int)$p_array[2], \'view_state\' ) == VS_PUBLIC
+							) {
+								$g_project_override = null;
+								return $p_array[1] .
+									string_get_bugnote_view_link(
+										$t_bug_id,
+										(int)$p_array[2],
+										null,
+										' . ( $p_detail_info ? 'true' : 'false' ) . ', ' . ( $p_fqdn ? 'true' : 'false' ) . '
+									);
+							}
+							$g_project_override = null;
+						}
+					}
+					return $p_array[0];
+					'
+				);
 		} else {
-			$string_process_bugnote_link_callback[$p_include_anchor][$p_detail_info][$p_fqdn] = create_function( '$p_array', '
-										# We might as well create the link here even if the bug
-										#  doesnt exist.  In the case above we dont want to do
-										#  the summary lookup on a non-existant bug.  But here, we
-										#  can create the link and by the time it is clicked on, the
-										#  bug may exist.
-										$t_bug_id = bugnote_get_field( (int)$p_array[2], \'bug_id\' );
-										if ( bug_exists( $t_bug_id ) ) {
-											return $p_array[1] . string_get_bugnote_view_url_with_fqdn( $t_bug_id, (int)$p_array[2], null );
-										} else {
-											return $p_array[0];
-										}
-										' );
+			$string_process_bugnote_link_callback[$p_include_anchor][$p_detail_info][$p_fqdn] =
+				create_function(
+					'$p_array',
+					'
+					# We might as well create the link here even if the bug
+					#  doesnt exist.  In the case above we dont want to do
+					#  the summary lookup on a non-existant bug.  But here, we
+					#  can create the link and by the time it is clicked on, the
+					#  bug may exist.
+					$t_bug_id = bugnote_get_field( (int)$p_array[2], \'bug_id\' );
+					if ( bug_exists( $t_bug_id ) ) {
+						return $p_array[1] . string_get_bugnote_view_url_with_fqdn( $t_bug_id, (int)$p_array[2], null );
+					} else {
+						return $p_array[0];
+					}
+					'
+				);
 		}
 	}
 	$p_string = preg_replace_callback( '/(^|[^\w])' . preg_quote( $t_tag, '/' ) . '(\d+)\b/', $string_process_bugnote_link_callback[$p_include_anchor][$p_detail_info][$p_fqdn], $p_string );
@@ -440,12 +461,15 @@ function string_process_bugnote_link( $p_string, $p_include_anchor = true, $p_de
 }
 
 /**
- * Detect URLs and email addresses in the string and replace them with href anchors
+ * Search email addresses and URLs for a few common protocols in the given
+ * string, and replace occurences with href anchors.
  * @param string $p_string
  * @return string
  */
 function string_insert_hrefs( $p_string ) {
 	static $s_url_regex = null;
+	static $s_email_regex = null;
+	static $s_anchor_regex = '/(<a[^>]*>.*?<\/a>)/is';
 
 	if( !config_get( 'html_make_links' ) ) {
 		return $p_string;
@@ -457,31 +481,55 @@ function string_insert_hrefs( $p_string ) {
 		ini_set( 'magic_quotes_sybase', false );
 	}
 
-	# Find any URL in a string and replace it by a clickable link
+	# Initialize static variables
 	if ( is_null( $s_url_regex ) ) {
+		# URL protocol. The regex accepts a small subset from the list of valid
+		# IANA permanent and provisional schemes defined in
+		# http://www.iana.org/assignments/uri-schemes/uri-schemes.xhtml
+		$t_url_protocol = '(?:https?|s?ftp|file|irc[6s]?|ssh|telnet|nntp|git|svn(?:\+ssh)?|cvs):\/\/';
+
 		# %2A notation in url's
 		$t_url_hex = '%[[:digit:]A-Fa-f]{2}';
 
 		# valid set of characters that may occur in url scheme. Note: - should be first (A-F != -AF).
-		$t_url_valid_chars = '-_.,!~*\';\/?%^\\\\:@&={\|}+$#[:alnum:]\pL';
-
-		$t_url_chars = "(?:${t_url_hex}|[${t_url_valid_chars}\(\)\[\]])";
-		$t_url_chars2 = "(?:${t_url_hex}|[${t_url_valid_chars}])";
+		$t_url_valid_chars       = '-_.,!~*\';\/?%^\\\\:@&={\|}+$#[:alnum:]\pL';
+		$t_url_chars             = "(?:${t_url_hex}|[${t_url_valid_chars}\(\)\[\]])";
+		$t_url_chars2            = "(?:${t_url_hex}|[${t_url_valid_chars}])";
 		$t_url_chars_in_brackets = "(?:${t_url_hex}|[${t_url_valid_chars}\(\)])";
-		$t_url_chars_in_parens    = "(?:${t_url_hex}|[${t_url_valid_chars}\[\]])";
+		$t_url_chars_in_parens   = "(?:${t_url_hex}|[${t_url_valid_chars}\[\]])";
 
 		$t_url_part1 = "${t_url_chars}";
 		$t_url_part2 = "(?:\(${t_url_chars_in_parens}*\)|\[${t_url_chars_in_brackets}*\]|${t_url_chars2})";
 
-		$s_url_regex = "/(([[:alpha:]][-+.[:alnum:]]*):\/\/(${t_url_part1}*?${t_url_part2}+))/sue";
+		$s_url_regex = "/(${t_url_protocol}(${t_url_part1}*?${t_url_part2}+))/su";
+
+		# e-mail regex
+		$s_email_regex = substr_replace( email_regex_simple(), '(?:mailto:)?', 1, 0 );
 	}
 
-	$p_string = preg_replace( $s_url_regex, "'<a href=\"'.rtrim('\\1','.').'\">\\1</a> [<a href=\"'.rtrim('\\1','.').'\" target=\"_blank\">^</a>]'", $p_string );
+	# Find any URL in a string and replace it by a clickable link
+	$t_function = create_function( '$p_match', '
+		$t_url_href = \'href="\' . rtrim( $p_match[1], \'.\' ) . \'"\';
+		return "<a ${t_url_href}>${p_match[1]}</a> [<a ${t_url_href} target=\"_blank\">^</a>]";
+	' );
+	$p_string = preg_replace_callback( $s_url_regex, $t_function, $p_string );
 	if( $t_change_quotes ) {
 		ini_set( 'magic_quotes_sybase', true );
 	}
 
-	$p_string = preg_replace( email_regex_simple(), '<a href="mailto:\0">\0</a>', $p_string );
+	# Find any email addresses in the string and replace them with a clickable
+	# mailto: link, making sure that we skip processing of any existing anchor
+	# tags, to avoid parts of URLs such as https://user@example.com/ or
+	# http://user:password@example.com/ to be not treated as an email.
+	$t_pieces = preg_split( $s_anchor_regex, $p_string, null, PREG_SPLIT_DELIM_CAPTURE );
+	$p_string = '';
+	foreach( $t_pieces as $piece ) {
+		if( preg_match( $s_anchor_regex, $piece ) ) {
+			$p_string .= $piece;
+		} else {
+			$p_string .= preg_replace( $s_email_regex, '<a href="mailto:\0">\0</a>', $piece );
+		}
+	}
 
 	return $p_string;
 }
